#version 150

#moj_import <fog.glsl>

uniform sampler2D Sampler0;
uniform sampler2D Sampler2;

uniform vec4 ColorModulator;
uniform float FogStart;
uniform float FogEnd;
uniform vec4 FogColor;

in float vertexDistance;
in vec4 vertexColor;
in vec2 texCoord0;

out vec4 fragColor;

// UI text color is weird, average it out
bool approx(float a, float b) {
    return abs(a - b) < (0.3 / 255.0);
}

void main() {
    vec4 color = texture(Sampler0, texCoord0) * vertexColor * ColorModulator;
    if (color.a < 0.1) {
        discard;
    }
    fragColor = linear_fog(color, vertexDistance, FogStart, FogEnd, FogColor);
    if (approx(vertexColor.r, (63.0 / 255.0)) && approx(vertexColor.g, (63.0 / 255.0)) && approx(vertexColor.b, (63.0 / 255.0))) {
        // Brighten up if too dark
        float brightness = (FogColor.r + FogColor.g + FogColor.b) / 3.0;
        float brightnessMultiplier = 1.0;
        if (brightness < 0.25) {
            brightnessMultiplier = (1.0 - brightness) * 10.0;
        }

        // Apply brightness multiplier
        fragColor.rgb *= brightnessMultiplier;

        // Apply tint and invert color
        fragColor.rgb = vec3(1.0) - FogColor.rgb;

        // Grayscale so it's still Minecrafty
        fragColor.rgb = vec3((fragColor.r + fragColor.g + fragColor.b) / 3.0);
    }
    if (FogColor.rgb == vec3(0.0)) {
        fragColor = linear_fog(color, vertexDistance, FogStart, FogEnd, FogColor);
    }
}